slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDGetMonitorContext

Gets the monitor context, as set by SVDMonitorSet() for the FIRST monitor only.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDGetMonitorContext(SVD svd,void *ctx)

Not Collective

### Input Parameter

| svd | - singular value solver context obtained from SVDCreate()

### Output Parameter

| ctx | - monitor context

### See Also

SVDMonitorSet()

### Level

intermediate

### Location

src/svd/interface/svdmon.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages